@@ -38,61 +38,94 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(object):
     def __init__(self):
-        self.BucketInfo = None
+        self.StorageInfo = None
         self.endpoint = None
 
-    def get_file(self, aws_json_file_name):
+    def get_file(self, storage_json_file_name):
         global save_path, target_name, bucket_info
         
         # meta file 저장하는 폴더 만들면, 이 경로는 수정돼야 함.
-        aws_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, aws_json_file_name)
+        storage_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, storage_json_file_name)
     
-        with open(aws_info_json_path) as jsonFile:
-            self.BucketInfo = json.load(jsonFile)
+        with open(storage_info_json_path) as jsonFile:
+            self.StorageInfo = json.load(jsonFile)
+    
+        ## define the target name
+        target_name = self.StorageInfo['target']
+        
+        
+        if 'host' in self.StorageInfo.keys():    # HDFS
             
-        BUCKET_TYPE = self.BucketInfo['bucketType']
-        BUCKET_NAME = self.BucketInfo['bucketName']
-        FILE_PATH = self.BucketInfo['filePath']
-        FILE_NAME = self.BucketInfo['fileName']
-        #FILE_TYPE = self.BucketInfo['fileType']
-        #FILE_DELIM = self.BucketInfo['fileDelim']
-        ACCESS_KEY = self.BucketInfo['myAccessKey']
-        SECRET_KEY = self.BucketInfo['mySecretKey']
-        REGION = self.BucketInfo['region']
-        URL = self.BucketInfo['endpoint']
+            ## path for saving data
+            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_hdfs')
+            if os.path.exists(save_dir) == False:
+                os.mkdir(save_dir)
+            else:
+                pass
+            
+            split_list = list(filter(None, self.StorageInfo['filePath'].split('/')))
+            
+            HOST = self.StorageInfo['host']
+            PORT = int(self.StorageInfo['port'])
+            FILE_PATH = self.StorageInfo['filePath']
+            FILE_DIR = '/'
+            for i in split_list[:len(split_list)-1]:
+                FILE_DIR = os.path.join(FILE_DIR, i)
+            FILE_NAME = split_list[-1]
+            
+            self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
+            self.save_path = os.path.join(save_dir, self.save_file_name)
+            self.endpoint = os.path.join('hdfs://', HOST, self.StorageInfo['port']) + FILE_PATH
+            
+            hdfs = HDFileSystem(host = HOST, port = PORT)
+            hdfs.ls(FILE_DIR)
+
+            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+            time.sleep(1)
+            hdfs.get(FILE_PATH, self.save_path)
+            logging.info(self.save_path)
         
-        ## define the target name 
-        target_name = self.BucketInfo['target']
+        
+        else:     # AWS-S3
+            BUCKET_TYPE = self.StorageInfo['bucketType']
+            BUCKET_NAME = self.StorageInfo['bucketName']
+            FILE_PATH = self.StorageInfo['filePath']
+            FILE_NAME = self.StorageInfo['fileName']
+            #FILE_TYPE = self.StorageInfo['fileType']
+            #FILE_DELIM = self.StorageInfo['fileDelim']
+            ACCESS_KEY = self.StorageInfo['myAccessKey']
+            SECRET_KEY = self.StorageInfo['mySecretKey']
+            REGION = self.StorageInfo['region']
+            URL = self.StorageInfo['endpoint']
 
-        ## path for saving data 
-        save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_AWS')  
-
-        if os.path.exists(save_dir) == False:
-            os.mkdir(save_dir)
-        else:
-            pass
+            ## path for saving data
+            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_aws')
+            if os.path.exists(save_dir) == False:
+                os.mkdir(save_dir)
+            else:
+                pass
   
-        self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
-        save_path = os.path.join(save_dir, self.save_file_name)
+            self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
+            save_path = os.path.join(save_dir, self.save_file_name)
 
-        # endpoint
-        pre_url = 'https://' + BUCKET_NAME + '.' + URL
-        self.endpoint = os.path.join(pre_url, FILE_PATH)
+            # endpoint
+            pre_url = 'https://' + BUCKET_NAME + '.' + URL
+            self.endpoint = os.path.join(pre_url, FILE_PATH)
 
-        client = boto3.client(BUCKET_TYPE,
-                              aws_access_key_id=ACCESS_KEY,
-                              aws_secret_access_key=SECRET_KEY,
-                              region_name=REGION)
+            client = boto3.client(BUCKET_TYPE,
+                                  aws_access_key_id=ACCESS_KEY,
+                                  aws_secret_access_key=SECRET_KEY,
+                                  region_name=REGION)
 
-        transfer = boto3.s3.transfer.S3Transfer(client)
+            transfer = boto3.s3.transfer.S3Transfer(client)
 
-        progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
-
-        sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
-        transfer.download_file(BUCKET_NAME, FILE_PATH, save_path, callback=progress)
-        logging.info(save_path)
+            progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
+    
+            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+            transfer.download_file(BUCKET_NAME, FILE_PATH, save_path, callback=progress)
+            logging.info(save_path)
         
-        bucket_info = self.BucketInfo
+        bucket_info = self.StorageInfo
     
     def set_slack(self, token = None, channel_id = None):
         self.token = token
