@@ -90,7 +90,7 @@ class accuinsight(object):
             storage_type = 'hdfs'
             
             split_1 = hdfs_uri.split('//')[1].split('/')
-            split_2 = [i.split(':') for i in split1 if ':' in i][0]
+            split_2 = [i.split(':') for i in split_1 if ':' in i][0]
             
             self.storage_info_from_set['host'] = split_2[0]
             self.storage_info_from_set['port'] = split_2[1]
