@@ -193,7 +193,9 @@ def get_visual_info_regressor(model, X_test):
     try:
         if len(str(preds[0]).split('.')[1]) >= 5:
             preds = np.round(preds, 4)
-            preds = list(map(float, np.array(preds, dtype = np.str).tolist()))
+            preds = list(map(float, np.array(preds, dtype = str).tolist()))
+        else:
+            preds = list(map(float, np.array(preds, dtype = str).tolist()))
     except TypeError:
         pass
     return(preds)
