@@ -4,6 +4,7 @@ import sys
 import json
 import subprocess
 from Accuinsight.modeler.core.LcConst import LcConst
+#from Accuinsight.modeler.utils import pyparams
 
 _BASH_RC_PATH = '/home/notebook/.bashrc'
 
@@ -60,7 +61,7 @@ def __get_current_file(target_path, target_file):
 
 
 def __install_package(package_name):
-    subprocess.check_call([sys.executable, "-m", "pip", "install", package])
+    subprocess.check_call([sys.executable, "-m", "pip", "install", package_name])
 
 
 def get_current_notebook():
